@@ -1,7 +1,7 @@
 package Mojo::Webqq;
 use strict;
 use Carp ();
-$Mojo::Webqq::VERSION = "2.0.8";
+$Mojo::Webqq::VERSION = "2.0.9";
 use Mojo::Webqq::Base 'Mojo::EventEmitter';
 use Mojo::Webqq::Log;
 use Mojo::Webqq::Cache;
@@ -226,7 +226,7 @@ sub new {
         }
     }
     $self->info("当前正在使用 Mojo-Webqq v" . $self->version);
-    $self->warn("当前版本与1.x.x版本不兼容，改动详情参见更新日志");
+    #$self->warn("当前版本与1.x.x版本不兼容，改动详情参见更新日志");
     $self->ioloop->reactor->on(error=>sub{
         my ($reactor, $err) = @_;
         $self->error("reactor error: " . Carp::longmess($err));
@@ -252,7 +252,7 @@ sub new {
     });
     $self->on(state_change=>sub{
         my $self = shift;
-        $self->save_state();
+        $self->save_state(@_);
     });
     $self->on(qrcode_expire=>sub{
         my($self) = @_;
