@@ -16,13 +16,15 @@ sub Mojo::Webqq::Client::_prepare_for_login {
     );
 
     my $regex_pattern =
-        'var\s*('
+        '(?:,|var )\s*?('
       . join( "|", @global_param )
-      . ')\s*=\s*encodeURIComponent\("(.*?)"\)';
+      . ')\s*?=\s*?encodeURIComponent\("(.*?)"\)';
     my $content = $self->http_get( $api_url, $headers);
     return 0 unless defined $content;
-    my %kv = map { url_escape($_) } $content =~ /$regex_pattern/g;
-    $self->$_($kv{$_}) for keys %kv;
+    eval{
+        my %kv = map { url_escape($_) } $content =~ /$regex_pattern/g;
+        $self->$_($kv{$_}) for keys %kv;
+    };
     $self->g_login_sig($self->search_cookie("pt_login_sig")) if not $self->g_login_sig;
     return 1;
 }
